#------------------------------------------------------------------------
# Welcome to the demo file for R commands
# isobxr package
# https://ttacail.github.io/isobxr_web/
# Theo Tacail
# 25/08/21
#------------------------------------------------------------------------
# This R document reunites step by step all the commands necessary to run the Getting started demonstrations
# for the main functions used in isobxr: run_isobxr, compose_isobxr, sweep_steady and sweep_dyn.
#------------------------------------------------------------------------
# If not installed yet, follow the installation instructions available here:
# https://ttacail.github.io/isobxr_web/vgn_01_Installation.html
#------------------------------------------------------------------------
# You can run the tutorial using the tutorial files embedded in the isobxr extdata.
# The function called below will automatically use these files.
#
# You can also get save these tutorial files to the local directory of your choice:
# Download the 1_ABC.zip file containing all tutorial files:
# https://ttacail.github.io/source/demos/1_ABC_tutorial.zip
# Unzip it and place it in the directory of your choice
#
# Note: Please avoid using a working directory linked to an online backup server (such as OneDrive),
# since it could cause some issues with adressing of output files in case of data saving.
# If done so, users are then advised to turn the backup server software offline during the use of isobxr functions.
#------------------------------------------------------------------------
# load the isobxr package
library(isobxr)
#------------------------------------------------------------------------
# If you run the tutorial locally, set the path to the 1_ABCD folder containing master xlsx files
# this could look like this:
workdir <- "/Users/username/Documents/1_ABC_tutorial"

# You can also run the tutorial functions as such, this will use the
# tutorial files embedded in the isobxr extdata.
# To this end, define the workdir as follows
workdir <- "/Users/username/Documents/1_ABC_tutorial"
# or
workdir <- "use_isobxr_demonstration_files"

# Note that the tutorial mode limits the number of optional outputs
# and prevents you to save outputs to any local working directory

#------------------------------------------------------------------------
#------------------- browse function documentations ----------------
#------------------------------------------------------------------------
?run_isobxr
?compose_isobxr
?sweep_steady
?sweep_dyn
?shinobxr_app

#------------------------------------------------------------------------
#------------------- 4 - Run_isobxr: tutorial ---------------------------
#------------------- (SINGLE RUNS with run_isobxr) ----------------------
#------------------------------------------------------------------------

# This section shows how to use run_isobxr for single box model runs
# This section corresponds to the commands for model runs used in the "4 - Run_isobxr: tutorial" vignette
# (https://ttacail.github.io/isobxr_web/vgn_04_Run_isobxr_tutorial.html)

####################################################################################
# Ex. 1. {ABC}, closed, balanced

run_isobxr(workdir = "/Users/username/Documents/1_ABC_tutorial", # isobxr master file work. dir.
           SERIES_ID = "ABC_closed_balanced", # series ID of the set of runs
           flux_list_name = "Fx1_ABC_closed_bal", # which flux list from FLUXES sheet
           coeff_list_name = "a1", # which coefficients list from COEFFS sheet
           t_lim = 2500, # how long do I want to run
           nb_steps = 250, # how many steps over this run duration
           time_units = c("d", "yr"), # run time units (days), plot time units (years)
           to_DIGEST_evD_PLOT = TRUE,
           to_DIGEST_CSV_XLS = TRUE,
           to_DIGEST_DIAGRAMS = TRUE) # export plot as pdf

####################################################################################
# Ex. 2: {ABC}, closed, unbalanced

run_isobxr(workdir = "/Users/username/Documents/1_ABC_tutorial", # isobxr master file work. dir.
           SERIES_ID = "ABC_closed_unbalanced", # series ID of the set of runs
           flux_list_name = "Fx2_ABC_closed_unbal", # which flux list from FLUXES sheet
           coeff_list_name = "a1", # which coefficients list from COEFFS sheet
           t_lim = 2500, # how long do I want to run
           nb_steps = 250, # how many steps over this run duration
           time_units = c("d", "yr"), # run time units (days), plot time units (years)
           to_DIGEST_evD_PLOT = TRUE,
           to_DIGEST_CSV_XLS = TRUE,
           to_DIGEST_DIAGRAMS = TRUE) # export plot as pdf

####################################################################################
# Ex. 3: {ABC}, open, balanced

run_isobxr(workdir = "/Users/username/Documents/1_ABC_tutorial", # isobxr master file work. dir.
           SERIES_ID = "ABC_open_balanced", # series ID of the set of runs
           flux_list_name = "Fx3_ABC_open_bal", # which flux list from FLUXES sheet
           coeff_list_name = "a1", # which coefficients list from COEFFS sheet
           t_lim = 25000, # how long do I want to run
           nb_steps = 2500, # how many steps over this run duration
           time_units = c("d", "yr"), # run time units (days), plot time units (years)
           to_DIGEST_evD_PLOT = TRUE,
           to_DIGEST_CSV_XLS = TRUE,
           to_DIGEST_DIAGRAMS = TRUE,
           evD_PLOT_time_as_log = FALSE) # export plot as pdf

####################################################################################
# Ex. 4: Additional forcing parameters

## Forcing the initial isotope compositions of the reservoirs
FORCING_DELTA <-
  data.frame(BOXES_ID = c("SOURCE", "C"),
             DELTA_INIT = c(-3, +5))

FORCING_DELTA

run_isobxr(workdir = "/Users/username/Documents/1_ABC_tutorial", # isobxr master file work. dir.
           SERIES_ID = "ABC_open_balanced_w_forcing_delta", # series ID of the set of runs
           flux_list_name = "Fx3_ABC_open_bal", # which flux list from FLUXES sheet
           coeff_list_name = "a1", # which coefficients list from COEFFS sheet
           t_lim = 25000, # how long do I want to run
           nb_steps = 2500, # how many steps over this run duration
           time_units = c("d", "yr"), # run time units (days), plot time units (years)
           to_DIGEST_evD_PLOT = TRUE,
           to_DIGEST_CSV_XLS = TRUE,
           to_DIGEST_DIAGRAMS = TRUE,
           FORCING_DELTA = FORCING_DELTA)

## Forcing the initial sizes of the reservoirs

FORCING_SIZE <-
  data.frame(BOXES_ID = c("B", "C"),
             SIZE_INIT = c(50, 1e6))

FORCING_SIZE

run_isobxr(workdir = "/Users/username/Documents/1_ABC_tutorial", # isobxr master file work. dir.
           SERIES_ID = "ABC_open_balanced_w_forcing_size", # series ID of the set of runs
           flux_list_name = "Fx3_ABC_open_bal", # which flux list from FLUXES sheet
           coeff_list_name = "a1", # which coefficients list from COEFFS sheet
           t_lim = 25000, # how long do I want to run
           nb_steps = 2500, # how many steps over this run duration
           time_units = c("d", "yr"), # run time units (days), plot time units (years)
           to_DIGEST_evD_PLOT = TRUE,
           to_DIGEST_CSV_XLS = TRUE,
           to_DIGEST_DIAGRAMS = TRUE,
           FORCING_SIZE = FORCING_SIZE)

#------------------------------------------------------------------------
#------------------- COMPOSE BOX MODEL SCENARIOS with compose_isobxr ----
#------------------------------------------------------------------------

# This section shows how to use compose_isobxr for box model scenarios
# This section corresponds to the commands for model runs used in the "Getting started 2: composite runs" vignette
# see https://ttacail.github.io/isobxr_web/vgn_06_compose_isobxr_tutorial.html#1_Prepare_tutorial

####################################################################################
# Ex. 1 : Changing intensity of fluxes
# see https://ttacail.github.io/isobxr_web/vgn_06_compose_isobxr_tutorial.html#3_Ex_1:_Changing_intensity_of_fluxes
compose_isobxr(workdir = "/Users/username/Documents/1_ABC_tutorial", # directory containing master files
               SERIES_ID = "ABC_change_balance", # name of the series ID
               time_units = c("d", "d"), # in/out time units for pdf plots
               COMPO_MASTER = "0_CPS_MASTER_changing_balance.xlsx", # compose master file
               plot_HIDE_BOXES_delta = c("SINK"), # hide in delta plots
               plot_HIDE_BOXES_size = c("SOURCE", "SINK"), # hide in size plots
               EACH_RUN_DIGEST = TRUE, # export the DIGEST for each run
               to_CPS_DIGEST_CSVs = TRUE) # export whole model to CSVs

# edit yourself the graphical outputs using the shinobxr app (only if outputs saved to local working directory):
workdir = workdir
shinobxr_app()

####################################################################################
# Ex. 2 : Changing source composition
# see https://ttacail.github.io/isobxr_web/vgn_06_compose_isobxr_tutorial.html#4_Ex_2_:_Changing_source_composition
compose_isobxr(workdir = "/Users/username/Documents/1_ABC_tutorial", # directory containing master files
               SERIES_ID = "ABC_change_source", # name of the series ID
               time_units = c("d", "yr"), # in/out time units for pdf plots
               COMPO_MASTER = "0_CPS_MASTER_changing_source.xlsx", # compose master file
               plot_HIDE_BOXES_delta = c("SINK"), # hide in delta plots
               plot_HIDE_BOXES_size = c("SOURCE", "SINK"), # hide in size plots
               EACH_RUN_DIGEST = F, # export the DIGEST for each run
               to_CPS_DIGEST_CSVs = TRUE) # export whole model to CSVs

# edit yourself the graphical outputs using the shinobxr app (only if outputs saved to local working directory):
workdir = workdir
shinobxr_app()

#------------------------------------------------------------------------
#---- sweep the space of parameters at final state with sweep_steady ----
#------------------------------------------------------------------------

# This section shows how to use sweep_steady
# This section corresponds to the commands for model run used in the "Using isboxr" vignette
# in the "Using sweep_steady" section;
# see https://ttacail.github.io/isobxr_web/vgn_07_sweep_steady.html#4_Tutorial_example

sweep_steady(workdir = "/Users/username/Documents/1_ABC_tutorial", # directory containing master files
             SERIES_ID = "ABC_sweep_steady_demo1", # name of the series ID
             time_units =  c("d", "yr"), # in/out time units for pdf plots
             EXPLO_MASTER = "0_SWEEP_STD_MASTER.xlsx", # name of sweep std master file
             EXPLO_AXIS_1 = data.frame(FROM = c("C"), # make alpha C to B vary between 1 and 1.0005
                                       TO = c("B"),
                                       ALPHA_MIN = 1,
                                       ALPHA_MAX = 1.0005,
                                       ALPHA_STEPS = 0.00005,
                                       EXPLO_TYPES = "EXPLO_1_ALPHA"),
             EXPLO_AXIS_2 = data.frame(FROM = c("A"), # make alpha A to C vary between 0.9996 and 1
                                       TO = c("C"),
                                       ALPHA_MIN = 0.9996,
                                       ALPHA_MAX = 1,
                                       ALPHA_STEPS = 0.00005,
                                       EXPLO_TYPES = "EXPLO_1_ALPHA"),
             to_STD_DIGEST_CSVs = T)

# edit yourself the graphical outputs using the shinobxr app (only if outputs saved to local working directory):
workdir = workdir
shinobxr_app()


#------------------------------------------------------------------------
#---- sweep the space of parameters after perturbation with sweep_dyn ---
#------------------------------------------------------------------------

# This section shows how to use sweep_dyn
# This section corresponds to the commands for model run used in the "Using isboxr" vignette
# in the "Using sweep_dyn" section;
# see https://ttacail.github.io/isobxr_web/vgn_08_sweep_dyn.html#4_Tutorial_example

sweep_dyn(workdir = "/Users/username/Documents/1_ABC_tutorial", # directory containing master files
          SERIES_ID = "ABC_change_source_sweep_dyn_demo1", # name of the series ID
          time_units = c("d", "yr"), # in/out time units for pdf plots
          EXPLO_MASTER = "0_SWEEP_DYN_MASTER.xlsx", # name of sweep dyn master file
          EXPLO_AXIS_1 = data.frame(FROM = c("A"), # make alpha A to C vary between 0.9988 and 1
                                    TO = c("C"),
                                    ALPHA_MIN = 0.9988,
                                    ALPHA_MAX = 1,
                                    ALPHA_STEPS = 0.0004,
                                    EXPLO_TYPES = "EXPLO_1_ALPHA"),
          EXPLO_AXIS_2 =  data.frame(BOXES_ID = c("B"), # make size of B vary between 500 and 4000
                                     SIZE_MIN = 500,
                                     SIZE_MAX = 4000,
                                     SIZE_STEPS = 500,
                                     EXPLO_TYPES = "EXPLO_1_SIZE"),
          to_DYN_DIGEST_CSVs = T)

# edit yourself the graphical outputs using the shinobxr app (only if outputs saved to local working directory):
workdir = workdir
shinobxr_app()

#------------------------------------------------------------------------
#---------------- Plotting with the isobxr plot editor app --------------
#------------------------------------------------------------------------

# This section shows how to use the shiny html locally hosted application for the plotting of isobxr outputs
# This section corresponds to the commands for model run used in the "Using isboxr" vignette
# in the "Plotting with the isobxr plot editor app" section;
# see https://ttacail.github.io/isobxr_web/vgn_09_runShinyPlots.html

# shinobxr_app requires that you saved the outputs
# of the compose_isobxr, sweep_steady or sweep_dyn runs to a local working directory (see save_run_outputs parameter)

# You need declare the workdir value where the output series directories were saved
# in this case, it corresponds to the path to the 1_ABCD folder:
workdir = workdir

# call the shinobxr_app function and follow the help provided within the app
# the app will open a window in your default web browser
shinobxr_app()
